#!/bin/bash

# We know how to build three toolchains:
#
#   TYPE= [blank] : Build cross compiler for TARGET (with optional GCC_CONFIG)
#                   (Don't package this up, it's not portable.)
#   TYPE=static   : Build portable cross compiler for TARGET
#                   (uses i686-linux-musl-cc --static)
#   TYPE=native   : Build native compiler for TARGET
#                   (uses cross $TARGET-cc --static)

if [ ! -z "$TYPE" ]
then
  if [ "$TYPE" == static ]
  then
    HOST=i686-linux-musl
    [ "$TARGET" = "$HOST" ] && PATH="$PWD/out-$HOST/bin:$PATH"
  else
    HOST="$TARGET"
    export NATIVE=y
  fi
  export PATH="$PWD/out-$HOST-static/bin:$PATH"
  export COMMON_CONFIG="CC=\"$HOST-gcc -static --static\" CXX=\"$HOST-g++ -static --static\""
  export -n TYPE HOST
fi

# Delete old temp files so every build is a full build
rm -rf build-"$TARGET" &&

[ -z "$TYPE" ] && TYPE=tempcross

make install OUTPUT="$PWD"/${TYPE}-${TARGET} -j$(nproc) TARGET=$TARGET \
  GCC_CONFIG="--disable-nls --disable-libquadmath --disable-decimal-float $GCC_CONFIG"
